@@ -54,10 +54,11 @@ plot1DNum = function(op, .alpha, .type, log, names, short.names,
   pl = pl + ggplot2::xlab(short.names)
   pl = pl + ggplot2::geom_rug(ggplot2::aes_string(alpha = ".alpha", colour = ".type"),
     sides = "b", size = 2L, data = op)
-  if (names %in% log)
+  if (names %in% log) {
     pl = pl + ggplot2::coord_trans(xtrans = "log10", limx = xlim)
-  else
+  } else {
     pl = pl + ggplot2::coord_cartesian(xlim = xlim)
+  }
   pl = pl + ggplot2::guides(alpha = FALSE)
   pl = pl + ggplot2::scale_alpha_continuous(range = c(max(1 / (iter + 1), 0.1), 1L))
   pl = pl + ggplot2::scale_colour_manual(name = "type",
@@ -103,7 +104,7 @@ plot1DDisc = function(op, .alpha, .type, log, names, short.names,
 # y.name: we can plot contour-lines for a singel y-variable if both x-variables
 # are numeric. in this case, op.y is the data.frame containing the y.variable
 plot2D = function(op, .alpha, .type, log, names, short.names, y.name = NULL, op.y = NULL,
-  space, iter, classes, xlim, ylim,  colours, size, ggplot.theme) {
+  space, iter, classes, xlim, ylim, colours, size, ggplot.theme) {
 
   op$.alpha = .alpha
   op$.type = .type
@@ -138,11 +139,12 @@ plot2D = function(op, .alpha, .type, log, names, short.names, y.name = NULL, op.
   }
 
   pl = ggplot2::ggplot()
-  pl = pl + ggplot2::geom_point(data = op, ggplot2::aes_string( x = names[1L], y = names[2L],
+  pl = pl + ggplot2::geom_point(data = op, ggplot2::aes_string(x = names[1L], y = names[2L],
     shape = ".type", colour = ".type", alpha = ".alpha"), size = size, position = pos)
   # add contour
-  if (!is.null(y.name))
+  if (!is.null(y.name)) {
     pl = pl + ggplot2::stat_contour(ggplot2::aes_string(x = names[1L], y = names[2L], z = y.name), data = df)
+  }
   pl = pl + title
   pl = pl + ggplot2::xlab(short.names[1L]) + ggplot2::ylab(short.names[2L])
   pl = pl + ggplot2::guides(alpha = FALSE)
@@ -153,16 +155,18 @@ plot2D = function(op, .alpha, .type, log, names, short.names, y.name = NULL, op.
   pl = pl + ggplot2::scale_alpha_continuous(range = c(max(1 / (iter + 1), 0.1), 1L))
   pl = pl + ggplot.theme
   if (classes[1L] == "numeric") {
-    if (names[1L] %in% log)
+    if (names[1L] %in% log) {
       pl = pl + ggplot2::scale_x_log10(limits = xlim)
-    else
+    } else {
       pl = pl + ggplot2::xlim(xlim)
+    }
   }
   if (classes[2L] == "numeric") {
-    if (names[2L] %in% log)
+    if (names[2L] %in% log) {
       pl = pl + ggplot2::scale_y_log10(limits = ylim)
-    else
+    } else {
       pl = pl + ggplot2::ylim(ylim)
+    }
   }
 
   return(pl)
@@ -172,13 +176,15 @@ plot2D = function(op, .alpha, .type, log, names, short.names, y.name = NULL, op.
 # Here we make a PCP using GGally::ggparcoord
 plotMultiD = function(op, .alpha, .type, log, names, short.names,
   space, iter, colours, size, scale, ggplot.theme) {
+
   args = list(columns = seq_along(names))
 
   # make every variable numeric and check for a log trafo
   for (var in names) {
     op[, var] = as.numeric(op[, var])
-    if (var %in% log)
+    if (var %in% log) {
       op[, var] = log10(op[, var])
+    }
   }
 
   op$.alpha = .alpha
@@ -198,7 +204,7 @@ plotMultiD = function(op, .alpha, .type, log, names, short.names,
     title = ggplot2::ggtitle("Y-Space")
   }
   pl = do.call(GGally::ggparcoord, args)
-  pl = pl + ggplot2::ylab ("scaled values")
+  pl = pl + ggplot2::ylab("scaled values")
   pl = pl + ggplot2::scale_x_discrete(labels = short.names)
   pl = pl + title
   pl = pl + ggplot2::guides(alpha = FALSE, size = FALSE)
@@ -216,17 +222,20 @@ multiVariablesOverTime = function(op, .alpha, dob, log, names, short.names,
   space, iter, colours, ggplot.theme) {
 
   # For rest variables, we can get a NA data.frame here. In this case, no plot
-  if (all(is.na(op[, names])))
+  if (all(is.na(op[, names]))) {
     return(NULL)
+  }
 
   # allow only log trafo of all variables in this plot
   log.var = names %in% log
-  if (any(log.var) && !all(log.var))
+  if (any(log.var) && !all(log.var)) {
     stop("If you want to apply a log trafo in an over.time.plot, you have to apply it to every variable.")
+  }
 
   for (var in names) {
-    if (!is.numeric(op[, var]))
+    if (!is.numeric(op[, var])) {
       warning(paste("Converting variable ", var, "to numeric for over time plot."))
+    }
     op[, var] = as.numeric(op[, var])
   }
 
@@ -251,7 +260,7 @@ multiVariablesOverTime = function(op, .alpha, dob, log, names, short.names,
   pl = pl + ggplot2::scale_x_continuous(breaks = function(x) pretty(x, n = min(5, iter + 1)))
 
   # fixed number of decimals:
-  fmt <- function(){
+  fmt <- function() {
     function(x) format(x, nsmall = 3, scientific = FALSE)
   }
 
@@ -270,12 +279,14 @@ oneVariableOverTime = function(op, .alpha, .type, dob, log, names, short.names,
   size.points, size.lines, colours, ggplot.theme) {
 
   # For rest variables, we can get a NA data.frame here. In this case, no plot
-  if (all(is.na(op[, names])))
+  if (all(is.na(op[, names]))) {
     return(NULL)
+  }
 
   # convert factor variables to numeric
-  if (!is.numeric(op[, names]))
+  if (!is.numeric(op[, names])) {
     warning(paste("Converting variable ", names, "to numeric for over time plot."))
+  }
   op[, names] = as.numeric(op[, names])
 
   # Some data  preproc. 2 Different datasets - one for init design, one for rest
@@ -300,21 +311,23 @@ oneVariableOverTime = function(op, .alpha, .type, dob, log, names, short.names,
   # add initial design points allays with jitter in x-direction,
   # if discrete also with jitter in y-direction
   if (length(na.omit(op.init.des[, names])) > 0L) {
-    if (is.numeric(op[, names]))
+    if (is.numeric(op[, names])) {
       pl = pl + ggplot2::geom_point(data = op.init.des, mapping = aes.points, size = size.points,
         position = ggplot2::position_jitter(height = 0.1))
-    else
+    } else {
       pl = pl + ggplot2::geom_point(data = op.init.des, mapping = aes.points, size = size.points,
         position = ggplot2::position_jitter(height = 0.1, width = 0.1))
+    }
   }
   # add sequential points, if discrete with jitter in y-direction
   # Add jitter for discrete variable
   if (length(na.omit(op.seq.opt[, names])) > 0L) {
-    if (is.numeric(op[, names]))
+    if (is.numeric(op[, names])) {
       pl = pl + ggplot2::geom_point(data = op.seq.opt, mapping = aes.points, size = size.points)
-    else
+    } else {
       pl = pl + ggplot2::geom_point(data = op.seq.opt, mapping = aes.points, size = size.points,
         position = ggplot2::position_jitter(height = 0.1, width = 0.1))
+    }
 
     # mean data for line plot for sequential data - only for numeric vars
     # Also ylims are only useful for numeric vars
@@ -326,7 +339,7 @@ oneVariableOverTime = function(op, .alpha, .type, dob, log, names, short.names,
   }
 
   # fixed number of decimals:
-  fmt <- function(){
+  fmt <- function() {
     function(x) format(x, nsmall = 3, scientific = FALSE)
   }
 
