@@ -8,12 +8,12 @@ test_that("simple num design", {
   des = generateDesign(13, ps1, lhs::randomLHS)
   expect_equal(nrow(des), 13)
   expect_equal(ncol(des), 1)
-  expect_true(is.numeric(des[,1]))
-  expect_true(des[,1] >= -2 && des[,1] <= 1)
+  expect_true(is.numeric(des[, 1]))
+  expect_true(all(des[, 1] >= -2) && all(des[, 1] <= 1))
   des = generateDesign(13, ps1, lhs::maximinLHS)
   expect_equal(nrow(des), 13)
   expect_equal(ncol(des), 1)
-  expect_true(des[,1] >= -2 && des[,1] <= 1)
+  expect_true(all(des[, 1] >= -2) && all(des[, 1] <= 1))
 })
 
 test_that("simple num/int design", {
@@ -25,17 +25,17 @@ test_that("simple num/int design", {
   des = generateDesign(13, ps2, lhs::randomLHS)
   expect_equal(nrow(des), 13)
   expect_equal(ncol(des), 2)
-  expect_true(is.numeric(des[,1]))
-  expect_true(des[,1] >= -2 && des[,1] <= 1)
-  expect_true(is.integer(des[,2]))
-  expect_true(des[,2] >= 10 && des[,2] <= 20)
+  expect_true(is.numeric(des[, 1]))
+  expect_true(all(des[, 1] >= -2) && all(des[, 1] <= 1))
+  expect_true(is.integer(des[, 2]))
+  expect_true(all(des[, 2] >= 10) && all(des[, 2] <= 20))
   des = generateDesign(13, ps2, lhs::maximinLHS)
   expect_equal(nrow(des), 13)
   expect_equal(ncol(des), 2)
-  expect_true(is.numeric(des[,1]))
-  expect_true(des[,1] >= -2 && des[,1] <= 1)
-  expect_true(is.integer(des[,2]))
-  expect_true(des[,2] >= 10 && des[,2] <= 20)
+  expect_true(is.numeric(des[, 1]))
+  expect_true(all(des[, 1] >= -2) && all(des[, 1] <= 1))
+  expect_true(is.integer(des[, 2]))
+  expect_true(all(des[, 2] >= 10) && all(des[, 2] <= 20))
 })
 
 test_that("simple num/int/discrete/log design", {
@@ -48,18 +48,18 @@ test_that("simple num/int/discrete/log design", {
   des = generateDesign(500, ps3)
   expect_equal(nrow(des), 500)
   expect_equal(ncol(des), 4)
-  expect_true(is.numeric(des[,1]))
-  expect_true(des[,1] >= -2 && des[,1] <= 1)
-  expect_true(is.integer(des[,2]))
-  expect_true(des[,2] >= 10 && des[,2] <= 20)
-  expect_true(is.factor(des[,3]))
-  expect_true(all(des[,3] %in% names(ps3$pars[[3]]$values)))
-  expect_equal(levels(des[,3]), names(ps3$pars[[3]]$values))
-  expect_true(is.logical(des[,4]))
-  tab = as.numeric(table(des[,3]))
-  expect_true(all(tab > 140 & tab < 180))
-  tab = as.numeric(table(des[,4]))
-  expect_true(all(tab > 200 & tab < 300))
+  expect_true(is.numeric(des[, 1]))
+  expect_true(all(des[, 1] >= -2) && all(des[, 1] <= 1))
+  expect_true(is.integer(des[, 2]))
+  expect_true(all(des[, 2] >= 10) && all(des[, 2] <= 20))
+  expect_true(is.factor(des[, 3]))
+  expect_true(all(des[, 3] %in% names(ps3$pars[[3]]$values)))
+  expect_equal(levels(des[, 3]), names(ps3$pars[[3]]$values))
+  expect_true(is.logical(des[, 4]))
+  tab = as.numeric(table(des[, 3]))
+  expect_true(all(tab > 140) && all(tab < 180))
+  tab = as.numeric(table(des[, 4]))
+  expect_true(all(tab > 200) && all(tab < 300))
 })
 
 test_that("num/int/disc vec design", {
@@ -73,45 +73,45 @@ test_that("num/int/disc vec design", {
   expect_equal(nrow(des), 13)
   expect_equal(ncol(des), 9)
   expect_equal(colnames(des), c("x1", "x2", "y1", "y2", "y3", "z1", "z2", "a1", "a2"))
-  expect_true(is.numeric(des[,1]))
-  expect_true(is.numeric(des[,2]))
-  expect_true(is.integer(des[,3]))
-  expect_true(is.integer(des[,4]))
-  expect_true(is.integer(des[,5]))
-  expect_true(is.factor(des[,6]))
-  expect_true(is.factor(des[,7]))
-  expect_true(is.logical(des[,8]))
-  expect_true(is.logical(des[,9]))
-  expect_true(des[,1] >= -2 && des[,1] <= 1)
-  expect_true(des[,2] >= -2 && des[,2] <= 1)
-  expect_true(des[,3] >= 10 && des[,3] <= 20)
-  expect_true(des[,4] >= 10 && des[,4] <= 20)
-  expect_true(des[,5] >= 10 && des[,5] <= 20)
-  expect_true(all(des[,6] %in% c("a", "b")))
-  expect_true(all(des[,7] %in% c("a", "b")))
-  expect_equal(levels(des[,6]), c("a", "b"))
-  expect_equal(levels(des[,7]), c("a", "b"))
+  expect_true(is.numeric(des[, 1]))
+  expect_true(is.numeric(des[, 2]))
+  expect_true(is.integer(des[, 3]))
+  expect_true(is.integer(des[, 4]))
+  expect_true(is.integer(des[, 5]))
+  expect_true(is.factor(des[, 6]))
+  expect_true(is.factor(des[, 7]))
+  expect_true(is.logical(des[, 8]))
+  expect_true(is.logical(des[, 9]))
+  expect_true(all(des[, 1] >= -2) && all(des[, 1] <= 1))
+  expect_true(all(des[, 2] >= -2) && all(des[, 2] <= 1))
+  expect_true(all(des[, 3] >= 10) && all(des[, 3] <= 20))
+  expect_true(all(des[, 4] >= 10) && all(des[, 4] <= 20))
+  expect_true(all(des[, 5] >= 10) && all(des[, 5] <= 20))
+  expect_true(all(des[, 6] %in% c("a", "b")))
+  expect_true(all(des[, 7] %in% c("a", "b")))
+  expect_equal(levels(des[, 6]), c("a", "b"))
+  expect_equal(levels(des[, 7]), c("a", "b"))
 })
 
 test_that("num/int vec design with trafo", {
   ps5 = makeParamSet(
-    makeNumericVectorParam("x", len = 2, lower = -2, upper = 1, trafo =  function(x) 2^x),
-    makeIntegerVectorParam("y", len = 3, lower = 10L, upper = 20L, trafo = function(x) 3L*x)
+    makeNumericVectorParam("x", len = 2, lower = -2, upper = 1, trafo = function(x) 2^x),
+    makeIntegerVectorParam("y", len = 3, lower = 10L, upper = 20L, trafo = function(x) 3L * x)
   )
   des = generateDesign(100, ps5, trafo = TRUE)
   expect_equal(nrow(des), 100)
   expect_equal(ncol(des), 5)
   expect_equal(colnames(des), c("x1", "x2", "y1", "y2", "y3"))
-  expect_true(is.numeric(des[,1]))
-  expect_true(is.numeric(des[,2]))
-  expect_true(is.integer(des[,3]))
-  expect_true(is.integer(des[,4]))
-  expect_true(is.integer(des[,5]))
-  expect_true(des[,1] >= 1/4 && des[,1] <= 2)
-  expect_true(des[,2] >= 1/4 && des[,2] <= 2)
-  expect_true(des[,3] >= 30 && des[,3] <= 60)
-  expect_true(des[,4] >= 30 && des[,4] <= 60)
-  expect_true(des[,5] >= 30 && des[,5] <= 60)
+  expect_true(is.numeric(des[, 1]))
+  expect_true(is.numeric(des[, 2]))
+  expect_true(is.integer(des[, 3]))
+  expect_true(is.integer(des[, 4]))
+  expect_true(is.integer(des[, 5]))
+  expect_true(all(des[, 1] >= 1 / 4) && all(des[, 1] <= 2))
+  expect_true(all(des[, 2] >= 1 / 4) && all(des[, 2] <= 2))
+  expect_true(all(des[, 3] >= 30) && all(des[, 3] <= 60))
+  expect_true(all(des[, 4] >= 30) && all(des[, 4] <= 60))
+  expect_true(all(des[, 5] >= 30) && all(des[, 5] <= 60))
 
   ps6 = makeParamSet(
     makeNumericVectorParam("x", len = 2, lower = 0, upper = 1, trafo = function(x) x / sum(x)),
@@ -122,13 +122,13 @@ test_that("num/int vec design with trafo", {
   expect_equal(nrow(des), 5)
   expect_equal(ncol(des), 6)
   expect_equal(colnames(des), c("x1", "x2", "y1", "y2", "z1", "z2"))
-  expect_true(is.numeric(des[,1]))
-  expect_true(is.numeric(des[,2]))
-  expect_true(is.integer(des[,3]))
-  expect_true(is.integer(des[,4]))
-  expect_equal(des[,1] + des[,2], rep(1, 5))
-  expect_equal(des[,3], rep(1, 5))
-  expect_equal(des[,4], rep(2, 5))
+  expect_true(is.numeric(des[, 1]))
+  expect_true(is.numeric(des[, 2]))
+  expect_true(is.integer(des[, 3]))
+  expect_true(is.integer(des[, 4]))
+  expect_equal(des[, 1] + des[, 2], rep(1, 5))
+  expect_equal(des[, 3], rep(1, 5))
+  expect_equal(des[, 4], rep(2, 5))
 
   # check that trafo can be switched off
   ps = makeParamSet(
@@ -166,15 +166,15 @@ test_that("nested requires", {
     makeDiscreteParam("discA", values = c("m", "w"), requires = quote(disc == "a")),
     makeNumericParam("realB", lower = -100, upper = 100, requires = quote(disc == "b")),
     makeDiscreteParam("discB", values = c("R", "NR"), requires = quote(disc == "b")),
-    makeNumericParam("realBR", lower = 0, upper = 2*pi, requires = quote(identical(discB, "R") && identical(disc, "b"))),
-    makeNumericParam("realBNR", lower = 0, upper = 2*pi, requires = quote(identical(discB, "NR") && identical(disc, "b")))
+    makeNumericParam("realBR", lower = 0, upper = 2 * pi, requires = quote(identical(discB, "R") && identical(disc, "b"))),
+    makeNumericParam("realBNR", lower = 0, upper = 2 * pi, requires = quote(identical(discB, "NR") && identical(disc, "b")))
   )
   des = generateDesign(50, par.set = ps7)
   expect_true(all(is.na(des[des$disc == "a", 5:8])))
   expect_true(all(is.na(des[des$disc == "b", 2:4])))
   expect_true(all(is.na(des[des$disc == "c", 2:8])))
-  expect_true(all(is.na(des[des$disc == "b" & des$discB == "NR",7])))
-  expect_true(all(is.na(des[des$disc == "b" & des$discB == "R",8])))
+  expect_true(all(is.na(des[des$disc == "b" & des$discB == "NR", 7])))
+  expect_true(all(is.na(des[des$disc == "b" & des$discB == "R", 8])))
 
   vals = dfRowsToList(des, ps7)
   oks = sapply(vals, isFeasible, par = ps7)
@@ -200,7 +200,7 @@ test_that("we dont drop levels in factors", {
     makeDiscreteParam("x", values = letters[5:1])
   )
   des = generateDesign(1, ps)
-  expect_true(is.factor(des$x) && levels(des$x) == letters[5:1])
+  expect_true(is.factor(des$x) && all(levels(des$x) == letters[5:1]))
 })
 
 test_that("list of further arguments passed to lhs function produces no error", {
@@ -232,8 +232,8 @@ test_that("vector params and forbidden regions", {
   )
 
   # the expression in 'forbidden' should not throw an error anymore
-  # See https://github.com/berndbischl/ParamHelpers/issues/51
+  # See https://github.com/mlr-org/ParamHelpers/issues/51
   res = generateDesign(100L, ps)
   expect_equal(nrow(res), 100L)
-  expect_numeric(rowSums(res[,c("x1","x2")]), lower = 0, upper = 1)
+  expect_numeric(rowSums(res[, c("x1", "x2")]), lower = 0, upper = 1)
 })
